Skip to contents

This retrieves a single episode. See seasons_episodes() for a whole season, and seasons_summary() for (potentially) all episodes of a show.

Usage

episodes_summary(id, season = 1L, episode = 1L, extended = "min")

episodes_summary() wraps endpoint /shows/:id/seasons/:season/episodes/:episode.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

season, episode

integer(1) [1L]: The season and episode number. If longer, e.g. 1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

# Get just this one episode with its ratings, votes, etc.
episodes_summary("breaking-bad", season = 1, episode = 1, extended = "full")
#> # A tibble: 1 × 21
#>   id         season episode title number_abs overview rating votes comment_count
#>   <chr>       <int>   <int> <chr>      <int> <chr>     <dbl> <int>         <int>
#> 1 breaking-…      1       1 Pilot          1 When an…   8.33  8315            24
#> # ℹ 12 more variables: first_aired <dttm>, updated_at <dttm>,
#> #   available_translations <list>, runtime <int>, episode_type <chr>,
#> #   original_title <chr>, after_credits <lgl>, during_credits <lgl>,
#> #   trakt <chr>, tvdb <chr>, imdb <chr>, tmdb <chr>