Skip to contents

Get similiar(ish) movies

Usage

movies_related(id, limit = 10L, extended = "min")

movies_related() wraps endpoint /movies/:id/related.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

limit

integer(1) [10L]: Number of items to return. Must be greater than 0 and will be coerced via as.integer().

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

movies_related("the-avengers-2012", limit = 5)
#> # A tibble: 5 × 9
#>   related_to         year title      imdb  slug  tmdb  trakt plex_guid plex_slug
#>   <chr>             <int> <chr>      <chr> <chr> <chr> <chr> <chr>     <chr>    
#> 1 the-avengers-2012  2011 Captain A… tt04… capt… 1771  1170  5d77682a… captain-…
#> 2 the-avengers-2012  2008 Iron Man   tt03… iron… 1726  1157  5d776829… iron-man 
#> 3 the-avengers-2012  2011 Thor       tt08… thor… 10195 5408  5d776834… thor     
#> 4 the-avengers-2012  2014 Guardians… tt20… guar… 1183… 82405 5d77696e… guardian…
#> 5 the-avengers-2012  2000 X-Men      tt01… x-me… 36657 23299 5d776868… x-men