Skip to contents

Get a single movie

Usage

movies_summary(id, extended = "min")

movies_summary() wraps endpoint /movies/:id.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

# Minimal info by default
movies_summary("inception-2010")
#> # A tibble: 1 × 8
#>    year title     imdb      slug           tmdb  trakt plex_guid       plex_slug
#>   <int> <chr>     <chr>     <chr>          <chr> <chr> <chr>           <chr>    
#> 1  2010 Inception tt1375666 inception-2010 27205 16662 5d77685333f255… inception
if (FALSE) { # \dontrun{
# Full information,  multiple movies
movies_summary(c("inception-2010", "the-dark-knight-2008"), extended = "full")
} # }