Skip to contents

These functions return the popular movies/shows on trakt.tv.

Usage

movies_popular(
  limit = 10,
  extended = "min",
  filters = NULL,
  query = NULL,
  years = NULL,
  genres = NULL,
  languages = NULL,
  countries = NULL,
  runtimes = NULL,
  ratings = NULL,
  certifications = NULL
)

shows_popular(
  limit = 10,
  extended = "min",
  filters = NULL,
  query = NULL,
  years = NULL,
  genres = NULL,
  languages = NULL,
  countries = NULL,
  runtimes = NULL,
  ratings = NULL,
  certifications = NULL,
  networks = NULL,
  status = NULL
)

movies_popular() wraps endpoint /movies/popular.

shows_popular() wraps endpoint /shows/popular.

Arguments

limit

integer(1) [10L]: Number of items to return. Must be greater than 0 and will be coerced via as.integer().

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

filters

A trakt_filters object created with filters_movies(), filters_shows(), or filters_episodes() that refines which items are returned. See filters for the full set of supported filters. Supplying filters as individual arguments (genres, years, networks, ...) is soft-deprecated in favour of this argument; if both are given, filters takes precedence.

query

character(1): Search string for titles and descriptions. For search_query() other fields are searched depending on the type of media. See the API docs for a full reference.

years

character | integer: 4-digit year (2010) or range, e.g. "2010-2020". Can also be an integer vector of length two which will be coerced appropriately, e.g. c(2010, 2020).

genres

character(n): Genre slug(s). See trakt_genres for a table of genres. Multiple values are allowed and will be concatenated.

languages

character(n): Two-letter language code(s). Also see trakt_languages for available languages (code and name).

countries

character(n): Two-letter country code(s). See trakt_countries.

runtimes

character | integer: Integer range in minutes, e.g. 30-90. Can also be an integer vector of length two which will be coerced appropriately.

ratings

character | integer: Integer range between 0 and 100. Can also be an integer vector of length two which will be coerced appropriately. Note that user-supplied ratings are in the range of 1 to 10, yet the ratings on the site itself are scaled to the range of 1 to 100.

certifications

character(n): Certification(s) like pg-13. Multiple values are allowed. Use trakt_certifications for reference. Note that there are different certifications for shows and movies.

networks

character(n): (Shows only) Network name like HBO. See trakt_networks for a list of known networks.

status

character(n): (Shows only) The status of the shows. One of "returning series", "in production", "planned", "canceled", or "ended".

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

The Dynamic Lists on trakt.tv

These functions access the automatically updated lists provided by trakt.tv. Each function comes in two flavors: Shows or movies. The following descriptions are adapted directly from the API reference.

  • Popular: Popularity is calculated using the rating percentage and the number of ratings.

  • Trending: Returns all movies/shows being watched right now. Movies/shows with the most users are returned first.

  • Played: Returns the most played (a single user can watch multiple times) movies/shows in the specified time period.

  • Watched: Returns the most watched (unique users) movies/shows in the specified time period.

  • Collected: Returns the most collected (unique users) movies/shows in the specified time period.

  • Anticipated: Returns the most anticipated movies/shows based on the number of lists a movie/show appears on. The functions for Played, Watched, Collected and Played each return the same additional variables besides the media information: watcher_count, play_count, collected_count, collector_count.

Examples

# Get the most popular German-language movies between 2000 and 2010
movies_popular(filters = filters_movies(languages = "de", years = c(2000, 2010)))
#> # A tibble: 10 × 7
#>     year title                                 imdb  plex$guid slug   tmdb trakt
#>    <int> <chr>                                 <chr> <chr>     <chr> <int> <int>
#>  1  2010 Shutter Island                        tt11… 5d776836… shut… 11324  6422
#>  2  2009 Inglourious Basterds                  tt03… 5d77683f… ingl… 16869 10322
#>  3  2009 2012                                  tt11… 5d77683b… 2012… 14161  8477
#>  4  2009 The Human Centipede (First Sequence)  tt14… 5d77686a… the-… 37169 23737
#>  5  2010 The A-Team                            tt04… 5d776864… the-… 34544 22059
#>  6  2010 Knight and Day                        tt10… 5d77686c… knig… 37834 24307
#>  7  2009 Angels & Demons                       tt08… 5d77683a… ange… 13448  7917
#>  8  2008 Quantum of Solace                     tt08… 5d776835… quan… 10764  5927
#>  9  2008 Indiana Jones and the Kingdom of the… tt03… 5d776824… indi…   217   176
#> 10  2010 From Paris with Love                  tt11… 5d776851… from… 26389 16053
#> # ℹ 1 more variable: plex$slug <chr>