Skip to contents

Similar to seasons_summary, but this function returns only metadata for a season.

Usage

seasons_season(id, seasons = 1L, extended = "min")

seasons_season() wraps endpoint /shows/:id/seasons/:season/info.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

seasons

integer(1) [1L]: The season(s) to get. Use 0 for specials.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Note

If you want to quickly gather episode data of all available seasons, see seasons_summary and use the episodes = TRUE parameter.

Examples

seasons_season("breaking-bad", 1)
#> # A tibble: 1 × 5
#>   number tmdb  tvdb  trakt plex_guid               
#>    <int> <chr> <chr> <chr> <chr>                   
#> 1      1 3572  30272 3950  602e61de66dfdb002c096b16

# Including all episode data:
seasons_season("breaking-bad", 1, extended = "full")
#> # A tibble: 1 × 16
#>   title    votes number rating network overview              updated_at         
#>   <chr>    <int>  <int>  <dbl> <lgl>   <chr>                 <dttm>             
#> 1 Season 1  3367      1   8.39 NA      "High school chemist… 2026-07-03 16:11:53
#> # ℹ 9 more variables: first_aired <dttm>, episode_count <int>,
#> #   total_runtime <int>, aired_episodes <int>, original_title <chr>,
#> #   tmdb <chr>, tvdb <chr>, trakt <chr>, plex_guid <chr>