Skip to contents

Get comments on a user-created list

Usage

user_list_comments(
  user = "me",
  list_id,
  sort = c("newest", "oldest", "likes", "replies"),
  extended = "min"
)

user_list_comments() wraps endpoint /users/:id/lists/:list_id/comments/:sort.

Arguments

user

character(1): Target username (or slug). Defaults to "me", the OAuth user. Can also be of length greater than 1, in which case the function is called on all user values separately and the result is combined.

list_id

The list identifier, either trakt ID or slug of the list. Can be optained via the website (URL slug) or e.g. user_lists.

sort

character(1) ["newest"]: Comment sort order, one of "newest", "oldest", "likes" or "replies".

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

if (FALSE) { # \dontrun{
user_list_comments("donxy", "1248149")
} # }