Get a user's profile
user_profile() wraps endpoint /users/:id.
Arguments
- user
character(1): Target username (orslug). Defaults to"me", the OAuth user. Can also be of length greater than 1, in which case the function is called on alluservalues separately and the result is combined.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Note
If the specified user is private, you need to be able to make an authenticated request and be friends with the user.
See also
Other user data:
user_collection(),
user_comments(),
user_history(),
user_likes(),
user_network(),
user_ratings(),
user_stats(),
user_watched(),
user_watchlist()
Other summary methods:
comments_comment(),
episodes_summary(),
movies_summary(),
people_summary(),
seasons_summary(),
shows_summary()