Skip to contents

Retrieve a user's media ratings

Usage

user_ratings(
  user = "me",
  type = c("movies", "seasons", "shows", "episodes"),
  rating = NULL,
  extended = "min",
  limit = NULL
)

user_ratings() wraps endpoint /users/:id/ratings/:type/:rating.

Arguments

user

character(1): Target username (or slug). Defaults to "me", the OAuth user. Can also be of length greater than 1, in which case the function is called on all user values separately and the result is combined.

type

character(1): Either "shows" or "movies". For season/episode-specific functions, values seasons or episodes are also allowed.

rating

integer(1) [NULL]: Optional rating between 1 and 10 to filter by.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

limit

integer(1) [NULL]: Number of items to return. If NULL (default), all items are returned.

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

if (FALSE) { # \dontrun{
user_ratings(user = "jemus42", "shows")
user_ratings(user = "sean", type = "movies")
} # }