Get all comments of a thing
Usage
movies_comments(
id,
sort = c("newest", "oldest", "likes", "replies"),
extended = "min",
limit = 10L
)
shows_comments(
id,
sort = c("newest", "oldest", "likes", "replies"),
extended = "min",
limit = 10L
)
seasons_comments(
id,
season = 1L,
sort = c("newest", "oldest", "likes", "replies"),
extended = "min",
limit = 10L
)
episodes_comments(
id,
season = 1L,
episode = 1L,
sort = c("newest", "oldest", "likes", "replies"),
extended = "min",
limit = 10L
)Source
movies_comments() wraps endpoint /movies/:id/comments/:sort.
shows_comments() wraps endpoint /shows/:id/comments/:sort.
seasons_comments() wraps endpoint /shows/:id/seasons/:season/comments/:sort.
episodes_comments() wraps endpoint /shows/:id/seasons/:season/episodes/:episode/comments/:sort.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- sort
character(1) ["newest"]: Comment sort order, one of "newest", "oldest", "likes" or "replies".- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).- limit
integer(1) [10L]: Number of items to return. Must be greater than0and will be coerced viaas.integer().- season, episode
integer(1) [1L]: The season and episode number. If longer, e.g.1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Functions
movies_comments(): Get comments for a movieshows_comments(): Get comments for a movieseasons_comments(): Get comments for a seasonepisodes_comments(): Get comments for an episode
See also
Other comment methods:
comments_comment(),
comments_trending(),
comments_updates(),
user_comments(),
user_list_comments()
Other movie data:
anticipated_media,
collected_media,
media_aliases,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
movies_boxoffice(),
movies_related(),
movies_releases(),
movies_summary(),
people_media(),
played_media,
popular_media,
trending_media,
updated_media,
watched_media
Other show data:
collected_media,
media_aliases,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
people_media(),
played_media,
shows_next_episode(),
shows_related(),
shows_summary(),
updated_media
Other season data:
media_lists,
media_people,
media_ratings(),
media_stats(),
seasons_episodes(),
seasons_season(),
seasons_summary()
Other episode data:
episodes_summary(),
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
seasons_episodes(),
seasons_summary(),
shows_next_episode()
Examples
movies_comments(193972)
#> # A tibble: 8 × 19
#> id comment spoiler review parent_id created_at
#> <int> <chr> <lgl> <lgl> <int> <dttm>
#> 1 1031140 "*Toy Story 4* was clear… FALSE FALSE 0 2026-08-23 02:46:08
#> 2 1010013 "Sigue ofreciendo un apa… FALSE FALSE 0 2026-08-01 12:19:40
#> 3 987101 "Ótimo filme, me deixou … FALSE FALSE 0 2026-07-13 03:08:04
#> 4 985863 "This film is the perfec… FALSE TRUE 0 2026-07-12 14:21:31
#> 5 982540 "I remember watching thi… FALSE FALSE 0 2026-07-10 10:14:57
#> 6 982049 "I know Bonnie is very y… FALSE FALSE 0 2026-07-10 00:01:04
#> 7 979529 "It wasn't like the prev… FALSE FALSE 0 2026-07-08 03:29:34
#> 8 978257 "Watched Toy Story 4 wit… TRUE FALSE 0 2026-07-07 05:31:36
#> # ℹ 13 more variables: updated_at <dttm>, replies <int>, likes <int>,
#> # user_rating <int>, language <chr>, username <chr>, private <lgl>,
#> # deleted <lgl>, user_name <chr>, vip <lgl>, vip_ep <lgl>, director <lgl>,
#> # user_slug <chr>
shows_comments(46241, sort = "likes")
#> # A tibble: 10 × 19
#> id comment spoiler review parent_id created_at
#> <int> <chr> <lgl> <lgl> <int> <dttm>
#> 1 4528 "The bright colours, the… FALSE FALSE 0 2014-12-27 21:04:43
#> 2 11599 "Television at its very … FALSE FALSE 0 2013-02-24 18:13:58
#> 3 39755 "Holy hell I can't belie… FALSE FALSE 0 2015-03-11 07:54:07
#> 4 143277 "After marathoning this … FALSE FALSE 0 2017-10-01 18:42:14
#> 5 436459 "EIGHT HOUR detailed You… FALSE FALSE 0 2022-01-15 08:59:48
#> 6 483035 "I've just finished watc… FALSE FALSE 0 2022-07-04 14:16:16
#> 7 171295 "If you like this style … FALSE FALSE 0 2018-04-20 01:20:40
#> 8 42940 "Looked interesting but … FALSE FALSE 0 2015-05-06 17:25:07
#> 9 814556 "FUCKING AMAZING, BEST T… FALSE FALSE 0 2025-05-20 12:03:34
#> 10 650557 "Spectacular show with s… FALSE FALSE 0 2024-03-02 04:09:50
#> # ℹ 13 more variables: updated_at <dttm>, replies <int>, likes <int>,
#> # user_rating <int>, language <chr>, username <chr>, private <lgl>,
#> # deleted <lgl>, user_name <chr>, vip <lgl>, vip_ep <lgl>, director <lgl>,
#> # user_slug <chr>
seasons_comments(46241, season = 1, sort = "likes")
#> # A tibble: 3 × 19
#> id comment spoiler review parent_id created_at
#> <int> <chr> <lgl> <lgl> <int> <dttm>
#> 1 386931 "This is the best season … FALSE TRUE 0 2021-06-29 04:59:56
#> 2 780275 "This reminds me of Dirk … FALSE FALSE 0 2025-03-02 21:53:20
#> 3 684618 "This is a hyper-stylized… TRUE TRUE 0 2024-06-15 23:54:34
#> # ℹ 13 more variables: updated_at <dttm>, replies <int>, likes <int>,
#> # user_rating <int>, language <chr>, username <chr>, private <lgl>,
#> # deleted <lgl>, user_name <chr>, vip <lgl>, vip_ep <lgl>, director <lgl>,
#> # user_slug <chr>
episodes_comments(46241, season = 1, episode = 2, sort = "likes")
#> # A tibble: 0 × 0