Get lists containing a movie, show, season, episode or person
Source:R/movies_lists.R
media_lists.RdGet lists containing a movie, show, season, episode or person
Usage
movies_lists(
id,
type = c("all", "personal", "official", "watchlists"),
sort = c("popular", "likes", "comments", "items", "added", "updated"),
limit = 10L,
extended = "min"
)
shows_lists(
id,
type = c("all", "personal", "official", "watchlists"),
sort = c("popular", "likes", "comments", "items", "added", "updated"),
limit = 10L,
extended = "min"
)
seasons_lists(
id,
season,
type = c("all", "personal", "official", "watchlists"),
sort = c("popular", "likes", "comments", "items", "added", "updated"),
limit = 10L,
extended = "min"
)
episodes_lists(
id,
season,
episode,
type = c("all", "personal", "official", "watchlists"),
sort = c("popular", "likes", "comments", "items", "added", "updated"),
limit = 10L,
extended = "min"
)
people_lists(
id,
type = c("all", "personal", "official", "watchlists"),
sort = c("popular", "likes", "comments", "items", "added", "updated"),
limit = 10L,
extended = "min"
)Source
movies_lists() wraps endpoint /movies/:id/lists/:type/:sort.
shows_lists() wraps endpoint /shows/:id/lists/:type/:sort.
seasons_lists() wraps endpoint /shows/:id/seasons/:season/lists/:type/:sort.
episodes_lists() wraps endpoint /shows/:id/seasons/:season/episodes/:episode/lists/:type/:sort.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- type
character(1) ["all"]: The type of list, one of "all", "personal", "official" or "watchlists".- sort
character(1) ["popular"]: Sort lists by one of "popular", "likes", "comments", "items", "added" or "updated".- limit
integer(1) [10L]: Number of items to return. Must be greater than0and will be coerced viaas.integer().- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).- season, episode
integer(1) [1L]: The season and episode number. If longer, e.g.1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Functions
movies_lists(): Lists containing a movie.shows_lists(): Lists containing a show.seasons_lists(): Lists containing a season.episodes_lists(): Lists containing an episode.people_lists(): Lists containing a person.
See also
Other list methods:
lists_popular(),
user_list(),
user_list_comments(),
user_list_items(),
user_lists()
Other movie data:
anticipated_media,
collected_media,
media_aliases,
media_comments,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
movies_boxoffice(),
movies_related(),
movies_releases(),
movies_summary(),
people_media(),
played_media,
popular_media,
trending_media,
watched_media
Other list methods:
lists_popular(),
user_list(),
user_list_comments(),
user_list_items(),
user_lists()
Other show data:
collected_media,
media_aliases,
media_comments,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
people_media(),
played_media,
shows_next_episode(),
shows_related(),
shows_summary()
Other list methods:
lists_popular(),
user_list(),
user_list_comments(),
user_list_items(),
user_lists()
Other season data:
media_comments,
media_people,
media_ratings(),
media_stats(),
seasons_episodes(),
seasons_season(),
seasons_summary()
Other list methods:
lists_popular(),
user_list(),
user_list_comments(),
user_list_items(),
user_lists()
Other episode data:
episodes_summary(),
media_comments,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
seasons_episodes(),
seasons_summary(),
shows_next_episode()
Other list methods:
lists_popular(),
user_list(),
user_list_comments(),
user_list_items(),
user_lists()
Other people data:
media_people,
people_media(),
people_summary()
Examples
if (FALSE) { # \dontrun{
movies_lists("190430", type = "personal", limit = 5)
} # }
if (FALSE) { # \dontrun{
shows_lists("46241")
} # }
if (FALSE) { # \dontrun{
seasons_lists("46241", season = 1)
} # }
if (FALSE) { # \dontrun{
episodes_lists("46241", season = 1, episode = 1)
} # }
if (FALSE) { # \dontrun{
people_lists("david-tennant")
people_lists("emilia-clarke", sort = "items")
} # }