Skip to contents

Returns all cast and crew for a show/movie, depending on how much data is available.

Usage

movies_people(id, extended = "min")

shows_people(id, guest_stars = FALSE, extended = "min")

seasons_people(id, season = 1L, guest_stars = FALSE, extended = "min")

episodes_people(
  id,
  season = 1L,
  episode = 1L,
  guest_stars = FALSE,
  extended = "min"
)

movies_people() wraps endpoint /movies/:id/people.

shows_people() wraps endpoint /shows/:id/people.

seasons_people() wraps endpoint /shows/:id/seasons/:season/people.

episodes_people() wraps endpoint /shows/:id/seasons/:season/episodes/:episode/people.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

guest_stars

logical(1) ["FALSE"]: Also include guest stars. This returns a lot of data, so use with care.

season, episode

integer(1) [1L]: The season and episode number. If longer, e.g. 1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.

Value

A list of one or more tibbles for cast and/or crew. The latter tibble objects are as flat as possible.

Note

As of 2019-09-30, there are two representations of character[s] and job[s]: One is a regular character variable, and the other is a list-column. The former is deprecated and only included for compatibility reasons.

Examples

if (FALSE) { # \dontrun{
movies_people("deadpool-2016")
shows_people("breaking-bad")
seasons_people("breaking-bad", season = 1)
episodes_people("breaking-bad", season = 1, episode = 1)
} # }