Returns all cast and crew for a show/movie, depending on how much data is available.
Usage
movies_people(id, extended = "min")
shows_people(id, guest_stars = FALSE, extended = "min")
seasons_people(id, season = 1L, guest_stars = FALSE, extended = "min")
episodes_people(
id,
season = 1L,
episode = 1L,
guest_stars = FALSE,
extended = "min"
)Source
movies_people() wraps endpoint /movies/:id/people.
shows_people() wraps endpoint /shows/:id/people.
seasons_people() wraps endpoint /shows/:id/seasons/:season/people.
episodes_people() wraps endpoint /shows/:id/seasons/:season/episodes/:episode/people.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).- guest_stars
logical(1) ["FALSE"]: Also include guest stars. This returns a lot of data, so use with care.- season, episode
integer(1) [1L]: The season and episode number. If longer, e.g.1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.
Value
A list of one or more tibbles for cast
and/or crew. The latter tibble objects are as flat as possible.
Note
As of 2019-09-30, there are two representations of character[s] and
job[s]:
One is a regular character variable, and the other is a list-column. The former is
deprecated and only included for
compatibility reasons.
See also
people_media, for the other direction: People that have credits in shows/movies.
Other people data:
media_lists,
people_media(),
people_summary()
Other movie data:
anticipated_media,
collected_media,
media_aliases,
media_comments,
media_lists,
media_ratings(),
media_stats(),
media_translations,
media_watching,
movies_boxoffice(),
movies_related(),
movies_releases(),
movies_summary(),
people_media(),
played_media,
popular_media,
trending_media,
watched_media
Other people data:
media_lists,
people_media(),
people_summary()
Other show data:
collected_media,
media_aliases,
media_comments,
media_lists,
media_ratings(),
media_stats(),
media_translations,
media_watching,
people_media(),
played_media,
shows_next_episode(),
shows_related(),
shows_summary()
Other people data:
media_lists,
people_media(),
people_summary()
Other season data:
media_comments,
media_lists,
media_ratings(),
media_stats(),
seasons_episodes(),
seasons_season(),
seasons_summary()
Other people data:
media_lists,
people_media(),
people_summary()
Other episode data:
episodes_summary(),
media_comments,
media_lists,
media_ratings(),
media_stats(),
media_translations,
media_watching,
seasons_episodes(),
seasons_summary(),
shows_next_episode()
Other people data:
media_lists,
people_media(),
people_summary()