Get who's watching a thing right now
Usage
movies_watching(id, extended = "min")
shows_watching(id, extended = "min")
seasons_watching(id, season = 1L, extended = "min")
episodes_watching(id, season = 1L, episode = 1L, extended = "min")Source
movies_watching() wraps endpoint /movies/:id/watching.
shows_watching() wraps endpoint /shows/:id/watching.
episodes_watching() wraps endpoint /shows/:id/seasons/:season/episodes/:episode/watching.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).- season, episode
integer(1) [1L]: The season and episode number. If longer, e.g.1:5, the function is vectorized and the output will be combined. This may result in a lot of API calls. Use wisely.
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Functions
movies_watching(): Who's watching a movie.shows_watching(): Who's watching a show.seasons_watching(): Who's watching a season.episodes_watching(): Who's watching an episode.
See also
Other movie data:
anticipated_media,
collected_media,
media_aliases,
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
movies_boxoffice(),
movies_related(),
movies_releases(),
movies_summary(),
people_media(),
played_media,
popular_media,
trending_media,
watched_media
Other show data:
collected_media,
media_aliases,
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
people_media(),
played_media,
shows_next_episode(),
shows_related(),
shows_summary()
Other episode data:
episodes_summary(),
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
seasons_episodes(),
seasons_summary(),
shows_next_episode()