Get a single movie
movies_summary() wraps endpoint /movies/:id.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
See also
Other movie data:
anticipated_media,
collected_media,
media_aliases,
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
movies_boxoffice(),
movies_related(),
movies_releases(),
people_media(),
played_media,
popular_media,
trending_media,
watched_media
Other summary methods:
comments_comment(),
episodes_summary(),
people_summary(),
seasons_summary(),
shows_summary(),
user_profile()
Examples
# Minimal info by default
movies_summary("inception-2010")
#> # A tibble: 1 × 29
#> year title votes genres rating status country runtime tagline trailer
#> <int> <chr> <int> <list> <dbl> <chr> <chr> <int> <chr> <chr>
#> 1 2010 Inception 85888 <chr [3]> 8.63 releas… us 148 Your m… https:…
#> # ℹ 19 more variables: homepage <chr>, language <chr>, overview <chr>,
#> # released <date>, languages <list>, subgenres <list>, updated_at <dttm>,
#> # after_credits <lgl>, certification <chr>, comment_count <int>,
#> # during_credits <lgl>, original_title <chr>, available_translations <list>,
#> # imdb <chr>, slug <chr>, tmdb <chr>, trakt <chr>, plex_guid <chr>,
#> # plex_slug <chr>
if (FALSE) { # \dontrun{
# Full information, multiple movies
movies_summary(c("inception-2010", "the-dark-knight-2008"), extended = "full")
} # }