Skip to contents

Returns all movies or shows where this person is in the cast or crew.

Usage

people_movies(id, extended = "min")

people_shows(id, extended = "min")

people_movies() wraps endpoint /people/:id/movies.

people_shows() wraps endpoint /people/:id/shows.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A list of one or more tibbles for cast and crew. The latter tibble objects are as flat as possible.

Details

Note that as of 2019-09-30, there are two representations of character[s] and job[s]: One is a regular character variable, and the other is a list-column. The singular is deprecated and only included for compatibility reasons.

Examples

if (FALSE) { # \dontrun{
people_movies("christopher-nolan")

people_shows("kit-harington")
} # }