Get a single person's details, like their various IDs. If extended is
"full", there will also be biographical data if available, e.g. their
birthday.
people_summary() wraps endpoint /people/:id.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
See also
Other people data:
media_lists,
media_people,
people_media()
Other summary methods:
comments_comment(),
episodes_summary(),
movies_summary(),
seasons_summary(),
shows_summary(),
user_profile()
Examples
# A single person's extended information
people_summary("bryan-cranston", "full")
#> # A tibble: 1 × 18
#> name death gender height birthday homepage biography birthplace
#> <chr> <chr> <chr> <dbl> <date> <chr> <chr> <chr>
#> 1 Bryan Cranston NA male 179. 1956-03-07 NA "Bryan Lee … Hollywood…
#> # ℹ 10 more variables: updated_at <dttm>, known_for_department <chr>,
#> # imdb <chr>, slug <chr>, tmdb <chr>, trakt <chr>, social_twitter <chr>,
#> # social_facebook <chr>, social_instagram <chr>, social_wikipedia <chr>
# Multiple people
people_summary(c("kit-harington", "emilia-clarke"))
#> # A tibble: 2 × 18
#> name death gender height birthday homepage biography birthplace
#> <chr> <chr> <chr> <int> <date> <chr> <chr> <chr>
#> 1 Kit Harington NA male 173 1986-12-26 NA "Christopher… Worcester…
#> 2 Emilia Clarke NA female 157 1986-10-23 NA "Emilia Isob… London, E…
#> # ℹ 10 more variables: updated_at <dttm>, known_for_department <chr>,
#> # imdb <chr>, slug <chr>, tmdb <chr>, trakt <chr>, social_twitter <chr>,
#> # social_facebook <chr>, social_instagram <chr>, social_wikipedia <chr>