Similar to seasons_summary, but this function returns full data for a single season, i.e. all the episodes of the season
seasons_episodes() wraps endpoint /shows/:id/seasons/:season?translations=.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- seasons
integer(1) [1L]: The season(s) to get. Use0for specials.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Note
If you want to quickly gather episode data of all available seasons,
see seasons_summary and use the episodes = TRUE parameter.
See also
Other season data:
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
seasons_season(),
seasons_summary()
Other episode data:
episodes_summary(),
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
seasons_summary(),
shows_next_episode()
Examples
seasons_episodes("breaking-bad", 1)
#> # A tibble: 7 × 8
#> title episode season imdb tmdb tvdb trakt plex_guid
#> <chr> <int> <int> <chr> <chr> <chr> <chr> <chr>
#> 1 Pilot 1 1 tt09… 62085 3492… 73482 5d9c0fc3…
#> 2 Cat's in the Bag... 2 1 tt10… 62086 3492… 73483 5d9c0fc3…
#> 3 ...And the Bag's in the River 3 1 tt10… 62087 3492… 73484 5d9c0fc3…
#> 4 Cancer Man 4 1 tt10… 62088 3492… 73485 5d9c0fc3…
#> 5 Gray Matter 5 1 tt10… 62089 3492… 73486 5d9c0fc3…
#> 6 Crazy Handful of Nothin' 6 1 tt10… 62090 3551… 73487 5d9c0fc3…
#> 7 A No Rough Stuff Type Deal 7 1 tt10… 62091 3525… 73488 5d9c0fc3…
# Including all episode data:
seasons_episodes("breaking-bad", 1, extended = "full")
#> # A tibble: 7 × 23
#> title votes episode rating season runtime overview released episode_abs
#> <chr> <int> <int> <dbl> <int> <int> <chr> <date> <int>
#> 1 Pilot 4758 1 8.35 1 59 When an… 2008-01-21 1
#> 2 Cat's in … 3951 2 8.11 1 49 Walt an… 2008-01-28 2
#> 3 ...And th… 3678 3 8.04 1 49 Walter … 2008-02-11 3
#> 4 Cancer Man 3543 4 7.93 1 49 Walter … 2008-02-18 4
#> 5 Gray Matt… 3469 5 7.95 1 49 Walter … 2008-02-25 5
#> 6 Crazy Han… 3503 6 8.54 1 49 The sid… 2008-03-03 6
#> 7 A No Roug… 3410 7 8.35 1 48 Walter … 2008-03-10 7
#> # ℹ 14 more variables: updated_at <dttm>, first_aired <dttm>,
#> # episode_type <chr>, after_credits <lgl>, comment_count <int>,
#> # during_credits <lgl>, original_title <chr>, available_translations <list>,
#> # effective_release_date <chr>, imdb <chr>, tmdb <chr>, tvdb <chr>,
#> # trakt <chr>, plex_guid <chr>