Skip to contents

Get a shows next or latest episode

Usage

shows_next_episode(id, extended = "min")

shows_last_episode(id, extended = "min")

shows_next_episode() wraps endpoint /shows/:id/next_episode.

shows_last_episode() wraps endpoint /shows/:id/last_episode.

Arguments

id

character(1): The ID of the item requested. Preferably the trakt ID (e.g. 1429). Other options are the trakt.tv slug (e.g. "the-wire") or imdb ID (e.g. "tt0306414"). Can also be of length greater than 1, in which case the function is called on all id values separately and the result is combined. See vignette("tRakt") for more details.

extended

character: Level of detail for the API response.

  • "min" (default): Minimal info (title, year, IDs). Omits the extended query param.

  • "full": Complete info including overview, ratings, runtime, etc.

  • "images": Minimal info plus image URLs (returned as a list-column).

  • "full,images": Complete info plus images.

  • "metadata": Collection endpoints only; adds video/audio metadata.

Multiple values can be combined as a comma-separated string (e.g. "full,images") or a character vector (e.g. c("full", "images")).

Value

A tibble(). If the function has a limit parameter (defaulting to 10), this will be the (maximum) number of rows of the tibble. If there are no results (or the API is unreachable), an empty tibble() is returned.

Examples

shows_next_episode("one-piece")
#> # A tibble: 0 × 0
shows_last_episode("one-piece", extended = "full")
#> # A tibble: 1 × 19
#>   season number title             number_abs overview rating votes comment_count
#>    <int>  <int> <chr>             <chr>      <chr>     <dbl> <int>         <int>
#> 1     22   1155 The Promised Hor… NA         York wa…   8.55   127             4
#> # ℹ 11 more variables: first_aired <dttm>, updated_at <dttm>, runtime <int>,
#> #   episode_type <chr>, original_title <chr>, after_credits <lgl>,
#> #   during_credits <lgl>, trakt <chr>, tvdb <chr>, imdb <chr>, tmdb <chr>