Get a single show
shows_summary() wraps endpoint /shows/:id.
Arguments
- id
character(1): The ID of the item requested. Preferably thetraktID (e.g.1429). Other options are the trakt.tvslug(e.g."the-wire") orimdbID (e.g."tt0306414"). Can also be of length greater than 1, in which case the function is called on allidvalues separately and the result is combined. Seevignette("tRakt")for more details.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
See also
Other show data:
collected_media,
media_aliases,
media_comments,
media_lists,
media_people,
media_ratings(),
media_stats(),
media_translations,
media_watching,
people_media(),
played_media,
shows_next_episode(),
shows_related()
Other summary methods:
comments_comment(),
episodes_summary(),
movies_summary(),
people_summary(),
seasons_summary(),
user_profile()
Examples
# Minimal info by default
shows_summary("breaking-bad")
#> # A tibble: 1 × 33
#> year title votes genres rating status country network runtime tagline
#> <int> <chr> <int> <list> <dbl> <chr> <chr> <chr> <int> <chr>
#> 1 2008 Breaking Bad 115197 <chr> 9.24 ended us AMC 50 Change…
#> # ℹ 23 more variables: trailer <chr>, homepage <chr>, language <chr>,
#> # overview <chr>, languages <list>, subgenres <list>, updated_at <dttm>,
#> # first_aired <dttm>, certification <chr>, comment_count <int>,
#> # aired_episodes <int>, original_title <chr>, available_translations <list>,
#> # airs_day <chr>, airs_time <chr>, airs_timezone <chr>, imdb <chr>,
#> # slug <chr>, tmdb <chr>, tvdb <chr>, trakt <chr>, plex_guid <chr>,
#> # plex_slug <chr>
if (FALSE) { # \dontrun{
# More information
shows_summary("breaking-bad", extended = "full")
} # }