Get a user's collected shows or movies
Usage
user_collection(
user = "me",
type = c("shows", "movies"),
unnest_episodes = FALSE,
extended = "min"
)Source
user_collection() wraps endpoint /users/:id/collection/:type.
Arguments
- user
character(1): Target username (orslug). Defaults to"me", the OAuth user. Can also be of length greater than 1, in which case the function is called on alluservalues separately and the result is combined.- type
character(1): Either"shows"or"movies". For season/episode-specific functions, valuesseasonsorepisodesare also allowed.- unnest_episodes
logical(1) [FALSE]: Unnests episode data usingtidyr::unnest()and returns one row per episode rather than one row per show.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Details
This function wraps the API method
/users/:user_id/collection/:type.
Note
The extended = "metadata" API parameter can be used to add media
information like media_type, resolution, audio, audio_channels and 3D
to the output. Combine with "full" as extended = "full,metadata".
See also
Other user data:
user_comments(),
user_history(),
user_likes(),
user_network(),
user_profile(),
user_ratings(),
user_stats(),
user_watched(),
user_watchlist()