Retrieve a single list a user has created together with information about the user.
Use extended = "full" to retrieve all user profile data, similiar to user_profile.
The returned variables trakt (list ID) or slug (list slug) can be used to
retrieve the list's items via user_list_items.
Arguments
- user
character(1): Target username (orslug). Defaults to"me", the OAuth user. Can also be of length greater than 1, in which case the function is called on alluservalues separately and the result is combined.- list_id
The list identifier, either
traktID orslugof the list. Can be optained via the website (URLslug) or e.g. user_lists.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
Note
In the embedded user data, name is renamed to user_name due
to duplication with e.g. list names,
and slug is renamed to user_slug for the same reason.
See also
user_list for only a single list.
user_list_items For the actual content of a list.
Other list methods:
lists_popular(),
media_lists,
user_list_comments(),
user_list_items(),
user_lists()