For private users, an authenticated request is required.
Usage
user_watched(
user = "me",
type = c("shows", "movies"),
noseasons = TRUE,
extended = "min"
)Source
user_watched() wraps endpoint /users/:id/watched/:type.
Arguments
- user
character(1): Target username (orslug). Defaults to"me", the OAuth user. Can also be of length greater than 1, in which case the function is called on alluservalues separately and the result is combined.- type
character(1): Either"shows"or"movies". For season/episode-specific functions, valuesseasonsorepisodesare also allowed.- noseasons
logical(1) [TRUE]: Only fortype = "show": Exclude detailed season data from output. This is advisable if you do not need per-episode data and want to be nice to the API.- extended
character: Level of detail for the API response."min"(default): Minimal info (title, year, IDs). Omits theextendedquery param."full": Complete info including overview, ratings, runtime, etc."images": Minimal info plus image URLs (returned as a list-column)."full,images": Complete info plus images."metadata": Collection endpoints only; adds video/audio metadata.
Multiple values can be combined as a comma-separated string (e.g.
"full,images") or a character vector (e.g.c("full", "images")).
Value
A tibble(). If the function has a limit parameter
(defaulting to 10), this will be the (maximum) number of rows of the tibble.
If there are no results (or the API is unreachable), an empty tibble() is returned.
See also
Other user data:
user_collection(),
user_comments(),
user_history(),
user_likes(),
user_network(),
user_profile(),
user_ratings(),
user_stats(),
user_watchlist()